@@ -19,6 +19,6 @@ fn page_folder_path() -> String {
     if Path::new("templates/pages").is_dir() {
         "templates/pages/".to_string()
     } else {
-        "src/templates/pages/".to_string()
+        "default_templates/pages/".to_string()
     }
 }
