@@ -5,6 +5,6 @@ pub fn call(template_name: &str) -> String {
     if Path::new(&user_file_path).exists() {
         user_file_path
     } else {
-        format!("src/templates/{}", template_name)
+        format!("default_templates/{}", template_name)
     }
 }
