@@ -18,7 +18,7 @@ fn replace_partials(template_content: &str) -> String {
 }
 
 fn get_partial_path(partial_match: &str) -> String {
-    let change_head = str::replace(partial_match, "{{!", "src/templates/partials/");
+    let change_head = str::replace(partial_match, "{{!", "default_templates/partials/");
     str::replace(&change_head, "}}", ".html")
 }
 
